@@ -140,14 +140,16 @@ sub build {
     . $lines[0];
   $lines[-1] .= qq/$append; \$_M; } };/;
 
+  # Done
   $self->code(join "\n", @lines);
+  $self->tree([]);
+
   return $self;
 }
 
 sub compile {
   my $self = shift;
 
-  # Shortcut
   return unless my $code = $self->code;
 
   # Compile
@@ -172,8 +174,6 @@ sub interpret {
     return $e if ref $e;
   }
   my $compiled = $self->compiled;
-
-  # Shortcut
   return unless $compiled;
 
   # Stacktrace
