@@ -11,12 +11,20 @@ use constant DEBUG => $ENV{MOJO_WEBSOCKET_DEBUG} || 0;
 # Unique value from the spec
 use constant GUID => '258EAFA5-E914-47DA-95CA-C5AB0DC85B11';
 
+# Opcodes
+use constant CONTINUATION => 0;
+use constant TEXT         => 1;
+use constant BINARY       => 2;
+use constant CLOSE        => 8;
+use constant PING         => 9;
+use constant PONG         => 10;
+
 # Core module since Perl 5.9.3
 use constant SHA1 => eval 'use Digest::SHA (); 1';
 
 has handshake => sub { Mojo::Transaction::HTTP->new };
 has [qw/masked on_message/];
-has max_websocket_size => sub { $ENV{MOJO_MAX_WEBSOCKET_SIZE} || 5242880 };
+has max_websocket_size => sub { $ENV{MOJO_MAX_WEBSOCKET_SIZE} || 262144 };
 
 sub client_challenge {
   my $self = shift;
@@ -32,13 +40,8 @@ sub client_close { shift->server_close(@_) }
 sub client_handshake {
   my $self = shift;
 
-  # Request
-  my $req = $self->req;
-
-  # Headers
-  my $headers = $req->headers;
-
   # Default headers
+  my $headers = $self->req->headers;
   $headers->upgrade('websocket')  unless $headers->upgrade;
   $headers->connection('Upgrade') unless $headers->connection;
   $headers->sec_websocket_protocol('mojo')
@@ -60,7 +63,7 @@ sub finish {
   my $self = shift;
 
   # Send closing handshake
-  $self->_send_frame(1, '');
+  $self->_send_frame(CLOSE, '');
 
   # Finish after writing
   $self->{_finished} = 1;
@@ -79,10 +82,7 @@ sub res            { shift->handshake->res(@_) }
 
 sub resume {
   my $self = shift;
-
-  # Resume
   $self->handshake->resume;
-
   return $self;
 }
 
@@ -96,22 +96,15 @@ sub send_message {
   $message = '' unless defined $message;
   encode 'UTF-8', $message;
 
-  $self->_send_frame(4, $message);
+  $self->_send_frame(TEXT, $message);
 }
 
 sub server_handshake {
   my $self = shift;
 
-  # Request
-  my $req = $self->req;
-
-  # Response
-  my $res = $self->res;
-
-  # Request headers
+  my $req         = $self->req;
+  my $res         = $self->res;
   my $req_headers = $req->headers;
-
-  # Response headers
   my $res_headers = $res->headers;
 
   # Handshake
@@ -143,27 +136,29 @@ sub server_read {
   while (my $frame = $self->_parse_frame) {
 
     # Op
-    my $op = $frame->[1] || 0;
+    my $op = $frame->[1] || CONTINUATION;
 
     # Ping
-    if ($op == 2) {
+    if ($op == PING) {
 
       # Pong
-      $self->_send_frame(3, $frame->[2]);
+      $self->_send_frame(PONG, $frame->[2]);
       next;
     }
 
     # Close
-    elsif ($op == 1) {
+    elsif ($op == CLOSE) {
       $self->finish;
       next;
     }
 
-    # Append
+    # Append chunk and check message size
     $self->{_message} .= $frame->[2];
+    $self->finish and last
+      if length $self->{_message} > $self->max_websocket_size;
 
-    # Continuation
-    next unless $op;
+    # No FIN bit (Continuation)
+    next unless $frame->[0];
 
     # Callback
     my $message = $self->{_message};
@@ -173,9 +168,6 @@ sub server_read {
     $self->$cb($message);
   }
 
-  # Check message size
-  $self->finish if length $self->{_message} > $self->max_websocket_size;
-
   # Resume
   $self->on_resume->($self);
 
@@ -204,54 +196,48 @@ sub server_write {
 sub _build_frame {
   my ($self, $op, $payload) = @_;
 
-  # Debug
   warn "BUILDING FRAME\n" if DEBUG;
 
   # Head
   my $frame = 0;
   vec($frame, 0, 8) = $op | 0b10000000;
 
-  # Debug
-  warn "PAYLOAD: $payload\n" if DEBUG;
-
   # Mask payload
-  if ($self->masked) {
-
-    # Debug
+  warn "PAYLOAD: $payload\n" if DEBUG;
+  my $masked = $self->masked;
+  if ($masked) {
     warn "MASKING PAYLOAD\n" if DEBUG;
-
-    # Mask
     my $mask = pack 'N', int(rand 9999999);
     $payload = $mask . _xor_mask($payload, $mask);
   }
 
   # Length
   my $len = length $payload;
+  $len -= 4 if $masked;
 
   # Empty prefix
   my $prefix = 0;
 
   # Small payload
   if ($len < 126) {
-    vec($prefix, 0, 8) = $len;
+    vec($prefix, 0, 8) = $masked ? ($len | 0b10000000) : $len;
     $frame .= $prefix;
   }
 
   # Extended payload (16bit)
   elsif ($len < 65536) {
-    vec($prefix, 0, 8) = 126;
+    vec($prefix, 0, 8) = $masked ? (126 | 0b10000000) : 126;
     $frame .= $prefix;
     $frame .= pack 'n', $len;
   }
 
   # Extended payload (64bit)
   else {
-    vec($prefix, 0, 8) = 127;
+    vec($prefix, 0, 8) = $masked ? (127 | 0b10000000) : 127;
     $frame .= $prefix;
     $frame .= pack 'NN', $len >> 32, $len & 0xFFFFFFFF;
   }
 
-  # Debug
   if (DEBUG) {
     warn 'HEAD: ' . unpack('B*', $frame) . "\n";
     warn "OPCODE: $op\n";
@@ -281,35 +267,24 @@ sub _challenge {
 sub _parse_frame {
   my $self = shift;
 
-  # Buffer
-  my $buffer = $self->{_read};
-
-  # Debug
   warn "PARSING FRAME\n" if DEBUG;
 
   # Head
+  my $buffer = $self->{_read};
   return unless length $buffer > 2;
   my $head = substr $buffer, 0, 2, '';
-
-  # Debug
   warn 'HEAD: ' . unpack('B*', $head) . "\n" if DEBUG;
 
   # FIN
   my $fin = (vec($head, 0, 8) & 0b10000000) == 0b10000000 ? 1 : 0;
-
-  # Debug
   warn "FIN: $fin\n" if DEBUG;
 
   # Opcode
   my $op = vec($head, 0, 8) & 0b00001111;
-
-  # Debug
   warn "OPCODE: $op\n" if DEBUG;
 
   # Length
   my $len = vec($head, 1, 8) & 0b01111111;
-
-  # Debug
   warn "LENGTH: $len\n" if DEBUG;
 
   # No payload
@@ -321,39 +296,32 @@ sub _parse_frame {
   # Extended payload (16bit)
   elsif ($len == 126) {
     return unless length $buffer > 2;
-    $head = substr $buffer, 0, 2, '';
-    $len = unpack 'n', $head;
-
-    # Debug
+    my $ext = substr $buffer, 0, 2, '';
+    $len = unpack 'n', $ext;
     warn "EXTENDED (16bit): $len\n" if DEBUG;
   }
 
   # Extended payload (64bit)
   elsif ($len == 127) {
     return unless length $buffer > 8;
-    $head = substr $buffer, 0, 8, '';
-    $len = unpack 'N', substr($head, 4, 4);
-
-    # Debug
+    my $ext = substr $buffer, 0, 8, '';
+    $len = unpack 'N', substr($ext, 4, 4);
     warn "EXTENDED (64bit): $len\n" if DEBUG;
   }
 
   # Payload
+  my $masked = vec($head, 1, 8) & 0b10000000;
+  $len += 4 if $masked;
   return unless length $buffer >= $len;
   my $payload = $len ? substr($buffer, 0, $len, '') : '';
 
   # Unmask payload
-  unless ($self->masked) {
-    $payload = _xor_mask($payload, substr($payload, 0, 4, ''));
-
-    # Debug
+  if ($masked) {
     warn "UNMASKING PAYLOAD\n" if DEBUG;
+    $payload = _xor_mask($payload, substr($payload, 0, 4, ''));
   }
 
-  # Debug
   warn "PAYLOAD: $payload\n" if DEBUG;
-
-  # Update buffer
   $self->{_read} = $buffer;
 
   return [$fin, $op, $payload];
@@ -428,7 +396,7 @@ Mask outgoing frames with XOR cipher and a random 32bit key.
   my $size = $ws->max_websocket_size;
   $ws      = $ws->max_websocket_size(1024);
 
-Maximum WebSocket message size in bytes, defaults to C<5242880>.
+Maximum WebSocket message size in bytes, defaults to C<262144>.
 
 =head2 C<on_message>
 
