@@ -17,7 +17,6 @@ use Mojo::Util qw/encode url_escape/;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
-# Debug
 use constant DEBUG => $ENV{MOJO_USERAGENT_DEBUG} || 0;
 
 # "You can't let a single bad experience scare you away from drugs."
@@ -39,17 +38,13 @@ sub DESTROY { shift->_cleanup }
 # "Ah, alcohol and night-swimming. It's a winning combination."
 sub build_form_tx {
   my $self = shift;
-
-  # URL
-  my $url = shift;
+  my $url  = shift;
 
   # Callback
   my $cb = pop @_ if ref $_[-1] && ref $_[-1] eq 'CODE';
 
-  # Encoding
-  my $encoding = shift;
-
   # Form
+  my $encoding = shift;
   my $form = ref $encoding ? $encoding : shift;
   $encoding = undef if ref $encoding;
 
@@ -87,10 +82,7 @@ sub build_form_tx {
         $hash->{file} = Mojo::Asset::Memory->new->add_chunk($content);
       }
 
-      # Content-Type
       $hash->{'Content-Type'} ||= 'application/octet-stream';
-
-      # Append
       push @{$params->params}, $name, $hash;
     }
 
@@ -99,12 +91,8 @@ sub build_form_tx {
   }
 
   # New transaction
-  my $tx = $self->build_tx(POST => $url);
-
-  # Request
-  my $req = $tx->req;
-
-  # Headers
+  my $tx      = $self->build_tx(POST => $url);
+  my $req     = $tx->req;
   my $headers = $req->headers;
   $headers->from_hash(ref $_[0] eq 'HASH' ? $_[0] : {@_});
 
@@ -112,46 +100,28 @@ sub build_form_tx {
   $headers->content_type('multipart/form-data') if $multipart;
   my $type = $headers->content_type || '';
   if ($type eq 'multipart/form-data') {
-
-    # Formdata
     my $form = $params->to_hash;
 
     # Parts
     my @parts;
     foreach my $name (sort keys %$form) {
-
-      # Part
       my $part = Mojo::Content::Single->new;
-
-      # Headers
-      my $h = $part->headers;
-
-      # Form
-      my $f = $form->{$name};
+      my $h    = $part->headers;
+      my $f    = $form->{$name};
 
       # File
       my $filename;
       if (ref $f eq 'HASH') {
-
-        # Filename
         $filename = delete $f->{filename} || $name;
         encode $encoding, $filename if $encoding;
         url_escape $filename, $Mojo::URL::UNRESERVED;
-
-        # Asset
         $part->asset(delete $f->{file});
-
-        # Headers
         $h->from_hash($f);
-
-        # Append
         push @parts, $part;
       }
 
       # Fields
       else {
-
-        # Content-Type
         my $type = 'text/plain';
         $type .= qq/;charset=$encoding/ if $encoding;
         $h->content_type($type);
@@ -161,8 +131,6 @@ sub build_form_tx {
           $part = Mojo::Content::Single->new(headers => $h);
           encode $encoding, $value if $encoding;
           $part->asset->add_chunk($value);
-
-          # Append
           push @parts, $part;
         }
       }
@@ -201,15 +169,9 @@ sub build_tx {
   my $self = shift;
 
   # New transaction
-  my $tx = Mojo::Transaction::HTTP->new;
-
-  # Request
+  my $tx  = Mojo::Transaction::HTTP->new;
   my $req = $tx->req;
-
-  # Method
   $req->method(shift);
-
-  # URL
   my $url = shift;
   $url = "http://$url" unless $url =~ /^\/|\:\/\//;
   $req->url->parse($url);
@@ -233,14 +195,8 @@ sub build_websocket_tx {
 
   # New WebSocket
   my ($tx, $cb) = $self->build_tx(GET => @_);
-
-  # Request
   my $req = $tx->req;
-
-  # URL
   my $url = $req->url;
-
-  # Scheme
   my $abs = $url->to_abs;
   if (my $scheme = $abs->scheme) {
     $scheme = $scheme eq 'wss' ? 'https' : 'http';
@@ -264,11 +220,13 @@ sub delete {
 
 sub detect_proxy {
   my $self = shift;
+
   $self->http_proxy($ENV{HTTP_PROXY}   || $ENV{http_proxy});
   $self->https_proxy($ENV{HTTPS_PROXY} || $ENV{https_proxy});
   if (my $no = $ENV{NO_PROXY} || $ENV{no_proxy}) {
     $self->no_proxy([split /,/, $no]);
   }
+
   return $self;
 }
 
@@ -326,20 +284,16 @@ sub start {
   # Non-blocking
   if ($cb) {
 
-    # Debug
-    warn "NEW NON-BLOCKING REQUEST\n" if DEBUG;
-
     # Switch to non-blocking
+    warn "NEW NON-BLOCKING REQUEST\n" if DEBUG;
     $self->_switch_non_blocking unless $self->{_nb};
 
     # Start
     return $self->_start_tx($tx, $cb);
   }
 
-  # Debug
-  warn "NEW BLOCKING REQUEST\n" if DEBUG;
-
   # Switch to blocking
+  warn "NEW BLOCKING REQUEST\n" if DEBUG;
   $self->_switch_blocking if $self->{_nb};
 
   # Quick start
@@ -360,19 +314,13 @@ sub test_server {
 
   # Server
   unless ($self->{_port}) {
-
-    # Loop
     my $loop = $self->{_loop} || $self->ioloop;
 
-    # Server
     my $server = $self->{_server} =
       Mojo::Server::Daemon->new(ioloop => $loop, silent => 1);
-
-    # Port
     my $port = $self->{_port} = $loop->generate_port;
     die "Couldn't find a free TCP port for testing.\n" unless $port;
 
-    # Listen
     $self->{_protocol} = $protocol ||= 'http';
     $server->listen(["$protocol://*:$port"]);
     $server->prepare_ioloop;
@@ -403,10 +351,8 @@ sub websocket {
 sub _cache {
   my ($self, $name, $id) = @_;
 
-  # Cache
-  my $cache = $self->{_cache} ||= [];
-
   # Enqueue
+  my $cache = $self->{_cache} ||= [];
   if ($id) {
 
     # Limit keep alive connections
@@ -416,24 +362,18 @@ sub _cache {
       $self->_drop($cached->[1]);
     }
 
-    # Add to cache
     push @$cache, [$name, $id] if $max;
-
     return $self;
   }
 
-  # Loop
-  my $loop = $self->{_loop};
-
   # Dequeue
+  my $loop = $self->{_loop};
   my $result;
   my @cache;
   for my $cached (@$cache) {
 
     # Search for name or id
     if (!$result && ($cached->[1] eq $name || $cached->[0] eq $name)) {
-
-      # Result
       my $id = $cached->[1];
 
       # Test connection
@@ -453,18 +393,14 @@ sub _cache {
 
 sub _cleanup {
   my $self = shift;
-
-  # Loop
   return unless my $loop = $self->{_loop};
 
   # Stop server
   delete $self->{_port};
   delete $self->{_server};
 
-  # Debug
-  warn "DROPPING ALL CONNECTIONS\n" if DEBUG;
-
   # Cleanup active connections
+  warn "DROPPING ALL CONNECTIONS\n" if DEBUG;
   my $cs = $self->{_cs} || {};
   $loop->drop($_) for keys %$cs;
 
@@ -475,37 +411,26 @@ sub _cleanup {
   }
 }
 
+sub _close { shift->_handle(pop, 1) }
+
 # "Where on my badge does it say anything about protecting people?
 #  Uh, second word, chief."
 sub _connect {
   my ($self, $tx, $cb) = @_;
-
-  # Check for specific connection id
-  my $id = $tx->connection;
-
-  # Loop
   my $loop = $self->{_loop};
 
   # Info
+  my $id = $tx->connection;
   my ($scheme, $address, $port) = $self->_tx_info($tx);
 
-  # Weaken
   weaken $self;
 
   # Keep alive connection
   $id ||= $self->_cache("$scheme:$address:$port");
   if ($id && !ref $id) {
-
-    # Debug
     warn "KEEP ALIVE CONNECTION ($scheme:$address:$port)\n" if DEBUG;
-
-    # Add new connection
     $self->{_cs}->{$id} = {cb => $cb, tx => $tx};
-
-    # Kept alive
     $tx->kept_alive(1);
-
-    # Connected
     $self->_connected($id);
   }
 
@@ -519,10 +444,8 @@ sub _connect {
       return if $self->_connect_proxy($tx, $cb);
     }
 
-    # Debug
-    warn "NEW CONNECTION ($scheme:$address:$port)\n" if DEBUG;
-
     # Connect
+    warn "NEW CONNECTION ($scheme:$address:$port)\n" if DEBUG;
     $id = $loop->connect(
       address  => $address,
       port     => $port,
@@ -532,14 +455,12 @@ sub _connect {
       tls_key  => $self->key,
       on_connect => sub { $self->_connected($_[1]) }
     );
-
-    # Add new connection
     $self->{_cs}->{$id} = {cb => $cb, tx => $tx};
   }
 
   # Callbacks
+  $loop->on_close($id => sub { $self->_close(@_) });
   $loop->on_error($id => sub { $self->_error(@_) });
-  $loop->on_hup($id => sub { $self->_hup(@_) });
   $loop->on_read($id => sub { $self->_read(@_) });
 
   return $id;
@@ -549,13 +470,10 @@ sub _connect {
 sub _connect_proxy {
   my ($self, $old, $cb) = @_;
 
-  # Request
   my $req = $old->req;
-
-  # URL
   my $url = $req->url;
 
-  # Proxy
+  # No proxy
   return unless my $proxy = $req->proxy;
 
   # WebSocket and/or HTTPS
@@ -610,13 +528,8 @@ sub _connect_proxy {
 sub _connected {
   my ($self, $id) = @_;
 
-  # Loop
   my $loop = $self->{_loop};
-
-  # Transaction
-  my $tx = $self->{_cs}->{$id}->{tx};
-
-  # Connection
+  my $tx   = $self->{_cs}->{$id}->{tx};
   $tx->connection($id);
 
   # Store connection information in transaction
@@ -678,10 +591,8 @@ sub _error {
 sub _finish_tx {
   my ($self, $tx, $cb) = @_;
 
-  # Response
-  my $res = $tx->res;
-
   # 400/500
+  my $res = $tx->res;
   $res->error($res->message, $res->code)
     if $res->is_status_class(400) || $res->is_status_class(500);
 
@@ -695,10 +606,7 @@ sub _finish_tx {
 sub _handle {
   my ($self, $id, $close) = @_;
 
-  # Connection
-  my $c = $self->{_cs}->{$id};
-
-  # Old transaction
+  my $c   = $self->{_cs}->{$id};
   my $old = $c->{tx};
 
   # WebSocket
@@ -706,11 +614,7 @@ sub _handle {
 
     # Finish transaction
     $old->client_close;
-
-    # Counter
     $self->{_processing} -= 1;
-
-    # Cleanup
     delete $self->{_cs}->{$id};
     $self->_drop($id, $close);
   }
@@ -737,7 +641,7 @@ sub _handle {
     # Extract cookies
     if (my $jar = $self->cookie_jar) { $jar->extract($old) }
 
-    # Counter
+    # Finished transaction
     $self->{_processing} -= 1;
 
     # Redirect or callback
@@ -749,20 +653,14 @@ sub _handle {
   $self->{_loop}->stop if !$self->{_nb} && !$self->{_processing};
 }
 
-sub _hup { shift->_handle(pop, 1) }
-
 # "Have you ever seen that Blue Man Group? Total ripoff of the Smurfs.
 #  And the Smurfs, well, they SUCK."
 sub _read {
   my ($self, $loop, $id, $chunk) = @_;
-
-  # Debug
   warn "< $chunk\n" if DEBUG;
 
-  # Connection
-  return unless my $c = $self->{_cs}->{$id};
-
   # Transaction
+  return unless my $c = $self->{_cs}->{$id};
   if (my $tx = $c->{tx}) {
 
     # Read
@@ -784,10 +682,8 @@ sub _read {
 sub _redirect {
   my ($self, $c, $old) = @_;
 
-  # Response
-  my $res = $old->res;
-
   # Code
+  my $res = $old->res;
   return unless $res->is_status_class('300');
   return if $res->code == 305;
 
@@ -795,10 +691,8 @@ sub _redirect {
   return unless my $location = $res->headers->location;
   $location = Mojo::URL->new($location);
 
-  # Request
-  my $req = $old->req;
-
   # Fix broken location without authority and/or scheme
+  my $req = $old->req;
   my $url = $req->url;
   $location->authority($url->authority) unless $location->authority;
   $location->scheme($url->scheme)       unless $location->scheme;
@@ -845,18 +739,13 @@ sub _start_tx {
     }
   }
 
-  # Request
-  my $req = $tx->req;
-
-  # URL
-  my $url = $req->url;
-
-  # Scheme
-  my $scheme = $url->scheme || '';
-
   # Detect proxy
   $self->detect_proxy if $ENV{MOJO_PROXY};
 
+  my $req    = $tx->req;
+  my $url    = $req->url;
+  my $scheme = $url->scheme || '';
+
   # Proxy
   if ($self->need_proxy($url->host)) {
 
@@ -884,10 +773,8 @@ sub _start_tx {
   # Connect
   return unless my $id = $self->_connect($tx, $cb);
 
-  # Weaken
-  weaken $self;
-
   # Resume callback
+  weaken $self;
   $tx->on_resume(sub { $self->_write($id) });
 
   # Counter
@@ -902,11 +789,8 @@ sub _switch_blocking {
 
   # Can't switch while processing non-blocking requests
   croak 'Non-blocking requests in progress' if $self->{_processing};
-
-  # Debug
   warn "SWITCHING TO BLOCKING MODE\n" if DEBUG;
 
-  # Cleanup
   $self->_cleanup;
 
   # Normal loop
@@ -919,11 +803,8 @@ sub _switch_non_blocking {
 
   # Can't switch while processing blocking requests
   croak 'Blocking request in progress' if $self->{_processing};
-
-  # Debug
   warn "SWITCHING TO NON-BLOCKING MODE\n" if DEBUG;
 
-  # Cleanup
   $self->_cleanup;
 
   # Global loop
@@ -934,13 +815,8 @@ sub _switch_non_blocking {
 sub _tx_info {
   my ($self, $tx) = @_;
 
-  # Request
-  my $req = $tx->req;
-
-  # URL
-  my $url = $req->url;
-
-  # Info
+  my $req    = $tx->req;
+  my $url    = $req->url;
   my $scheme = $url->scheme || 'http';
   my $host   = $url->ihost;
   my $port   = $url->port;
@@ -962,25 +838,14 @@ sub _tx_info {
 sub _upgrade {
   my ($self, $id) = @_;
 
-  # Connection
-  my $c = $self->{_cs}->{$id};
-
-  # Last transaction
+  my $c   = $self->{_cs}->{$id};
   my $old = $c->{tx};
 
-  # Request
-  my $req = $old->req;
-
-  # Headers
-  my $headers = $req->headers;
-
   # No upgrade request
-  return unless $headers->upgrade;
-
-  # Response
-  my $res = $old->res;
+  return unless $old->req->headers->upgrade;
 
   # Handshake failed
+  my $res = $old->res;
   return unless ($res->code || '') eq '101';
 
   # Upgrade to WebSocket transaction
@@ -995,10 +860,8 @@ sub _upgrade {
   # Upgrade connection timeout
   $self->{_loop}->connection_timeout($id, $self->websocket_timeout);
 
-  # Weaken
-  weaken $self;
-
   # Resume callback
+  weaken $self;
   $new->on_resume(sub { $self->_write($id) });
 
   return $new;
@@ -1008,25 +871,18 @@ sub _upgrade {
 sub _write {
   my ($self, $id) = @_;
 
-  # Connection
-  return unless my $c = $self->{_cs}->{$id};
-
-  # Transaction
+  # Writing
+  return unless my $c  = $self->{_cs}->{$id};
   return unless my $tx = $c->{tx};
-
-  # Not writing
   return unless $tx->is_writing;
 
-  # Chunk
+  # Get chunk
   my $chunk = $c->{tx}->client_write;
 
   # Still writing
   my $cb;
   if ($tx->is_writing) {
-
-    # Weaken
     weaken $self;
-
     $cb = sub { $self->_write($id) };
   }
 
@@ -1035,9 +891,7 @@ sub _write {
 
   # Finish
   $self->_handle($id) if $tx->is_done;
-
-  # Debug
-  warn "> $chunk\n" if DEBUG;
+  warn "> $chunk\n"   if DEBUG;
 }
 
 1;
