@@ -1,37 +1,30 @@
 package Mojolicious::Command::Cgi;
-
-use strict;
-use warnings;
-
-use base 'Mojo::Command';
+use Mojo::Base 'Mojo::Command';
 
 use Mojo::Server::CGI;
 
 use Getopt::Long 'GetOptions';
 
-__PACKAGE__->attr(description => <<'EOF');
+has description => <<'EOF';
 Start application with CGI.
 EOF
-__PACKAGE__->attr(usage => <<"EOF");
+has usage => <<"EOF";
 usage: $0 cgi [OPTIONS]
 
 These options are available:
   --nph   Enable non-parsed-header mode.
 EOF
 
-# Hi, Super Nintendo Chalmers!
+# "Hi, Super Nintendo Chalmers!"
 sub run {
-    my $self = shift;
-    my $cgi  = Mojo::Server::CGI->new;
+  my $self = shift;
 
-    # Options
-    local @ARGV = @_ if @_;
-    GetOptions(nph => sub { $cgi->nph(1) });
+  my $cgi = Mojo::Server::CGI->new;
+  local @ARGV = @_ if @_;
+  GetOptions(nph => sub { $cgi->nph(1) });
+  $cgi->run;
 
-    # Run
-    $cgi->run;
-
-    return $self;
+  return $self;
 }
 
 1;
@@ -43,10 +36,10 @@ Mojolicious::Command::Cgi - CGI Command
 
 =head1 SYNOPSIS
 
-    use Mojolicious::Command::CGI;
+  use Mojolicious::Command::CGI;
 
-    my $cgi = Mojolicious::Command::CGI->new;
-    $cgi->run(@ARGV);
+  my $cgi = Mojolicious::Command::CGI->new;
+  $cgi->run(@ARGV);
 
 =head1 DESCRIPTION
 
@@ -59,15 +52,15 @@ and implements the following new ones.
 
 =head2 C<description>
 
-    my $description = $cgi->description;
-    $cgi            = $cgi->description('Foo!');
+  my $description = $cgi->description;
+  $cgi            = $cgi->description('Foo!');
 
 Short description of this command, used for the command list.
 
 =head2 C<usage>
 
-    my $usage = $cgi->usage;
-    $cgi      = $cgi->usage('Foo!');
+  my $usage = $cgi->usage;
+  $cgi      = $cgi->usage('Foo!');
 
 Usage information for this command, used for the help screen.
 
@@ -78,7 +71,7 @@ implements the following new ones.
 
 =head2 C<run>
 
-    $cgi = $cgi->run(@ARGV);
+  $cgi = $cgi->run(@ARGV);
 
 Run this command.
 
