@@ -1,18 +1,14 @@
 package Mojolicious::Command::Daemon;
-
-use strict;
-use warnings;
-
-use base 'Mojo::Command';
+use Mojo::Base 'Mojo::Command';
 
 use Mojo::Server::Daemon;
 
 use Getopt::Long 'GetOptions';
 
-__PACKAGE__->attr(description => <<'EOF');
+has description => <<'EOF';
 Start application with HTTP 1.1 and WebSocket server.
 EOF
-__PACKAGE__->attr(usage => <<"EOF");
+has usage => <<"EOF";
 usage: $0 daemon [OPTIONS]
 
 These options are available:
@@ -33,34 +29,31 @@ These options are available:
   --websocket <seconds>   Set WebSocket timeout, defaults to 300.
 EOF
 
-
-# This is the worst thing you've ever done.
-# You say that so often that it lost its meaning.
+# "This is the worst thing you've ever done.
+#  You say that so often that it lost its meaning."
 sub run {
-    my $self   = shift;
-    my $daemon = Mojo::Server::Daemon->new;
+  my $self   = shift;
+  my $daemon = Mojo::Server::Daemon->new;
 
-    # Options
-    local @ARGV = @_ if @_;
-    my @listen;
-    GetOptions(
-        'backlog=i'   => sub { $daemon->backlog($_[1]) },
-        'clients=i'   => sub { $daemon->max_clients($_[1]) },
-        'group=s'     => sub { $daemon->group($_[1]) },
-        'keepalive=i' => sub { $daemon->keep_alive_timeout($_[1]) },
-        'listen=s'    => \@listen,
-        'proxy' => sub { $ENV{MOJO_REVERSE_PROXY} = 1 },
-        reload  => sub { $ENV{MOJO_RELOAD}        = 1 },
-        'requests=i'  => sub { $daemon->max_requests($_[1]) },
-        'user=s'      => sub { $daemon->user($_[1]) },
-        'websocket=i' => sub { $daemon->websocket_timeout($_[1]) }
-    );
-    $daemon->listen(\@listen) if @listen;
+  local @ARGV = @_ if @_;
+  my @listen;
+  GetOptions(
+    'backlog=i'   => sub { $daemon->backlog($_[1]) },
+    'clients=i'   => sub { $daemon->max_clients($_[1]) },
+    'group=s'     => sub { $daemon->group($_[1]) },
+    'keepalive=i' => sub { $daemon->keep_alive_timeout($_[1]) },
+    'listen=s'    => \@listen,
+    'proxy' => sub { $ENV{MOJO_REVERSE_PROXY} = 1 },
+    reload  => sub { $ENV{MOJO_RELOAD}        = 1 },
+    'requests=i'  => sub { $daemon->max_requests($_[1]) },
+    'user=s'      => sub { $daemon->user($_[1]) },
+    'websocket=i' => sub { $daemon->websocket_timeout($_[1]) }
+  );
 
-    # Run
-    $daemon->run;
+  $daemon->listen(\@listen) if @listen;
+  $daemon->run;
 
-    return $self;
+  return $self;
 }
 
 1;
@@ -72,10 +65,10 @@ Mojolicious::Command::Daemon - Daemon Command
 
 =head1 SYNOPSIS
 
-    use Mojolicious::Command::Daemon;
+  use Mojolicious::Command::Daemon;
 
-    my $daemon = Mojolicious::Command::Daemon->new;
-    $daemon->run(@ARGV);
+  my $daemon = Mojolicious::Command::Daemon->new;
+  $daemon->run(@ARGV);
 
 =head1 DESCRIPTION
 
@@ -89,15 +82,15 @@ and implements the following new ones.
 
 =head2 C<description>
 
-    my $description = $daemon->description;
-    $daemon         = $daemon->description('Foo!');
+  my $description = $daemon->description;
+  $daemon         = $daemon->description('Foo!');
 
 Short description of this command, used for the command list.
 
 =head2 C<usage>
 
-    my $usage = $daemon->usage;
-    $daemon   = $daemon->usage('Foo!');
+  my $usage = $daemon->usage;
+  $daemon   = $daemon->usage('Foo!');
 
 Usage information for this command, used for the help screen.
 
@@ -108,7 +101,7 @@ and implements the following new ones.
 
 =head2 C<run>
 
-    $daemon = $daemon->run(@ARGV);
+  $daemon = $daemon->run(@ARGV);
 
 Run this command.
 
