@@ -9,8 +9,6 @@ use constant DEBUG => $ENV{MOJO_CONFIG_DEBUG} || 0;
 # "Who are you, my warranty?!"
 sub load {
   my ($self, $file, $conf, $app) = @_;
-
-  # Debug
   $app->log->debug(qq/Reading config file "$file"./);
 
   # Slurp UTF-8 file
@@ -37,8 +35,6 @@ sub parse {
 
 sub register {
   my ($self, $app, $conf) = @_;
-
-  # Plugin config
   $conf ||= {};
 
   # File
@@ -54,16 +50,12 @@ sub register {
     # Default extension
     $file .= '.' . ($conf->{ext} || 'conf');
   }
-
-  # Debug
   warn "CONFIG FILE $file\n" if DEBUG;
 
   # Mode specific config file
   my $mode;
   if ($file =~ /^(.*)\.([^\.]+)$/) {
     $mode = join '.', $1, $app->mode, $2;
-
-    # Debug
     warn "MODE SPECIFIC CONFIG FILE $mode\n" if DEBUG;
   }
 
@@ -83,17 +75,12 @@ sub register {
     # All missing
     die qq/Config file "$file" missing, maybe you need to create it?\n/
       unless $conf->{default};
-
-    # Debug
     $app->log->debug(qq/Config file "$file" missing, using default config./);
   }
 
-  # Merge with mode specific config file
-  if (defined $mode && -e $mode) {
-    $config = {%$config, %{$self->load($mode, $conf, $app)}};
-  }
-
-  # Merge
+  # Merge everything
+  $config = {%$config, %{$self->load($mode, $conf, $app)}}
+    if defined $mode && -e $mode;
   $config = {%{$conf->{default}}, %$config} if $conf->{default};
 
   # Add "config" helper
